@@ -177,11 +177,7 @@ Partition* PartitionManagerWidget::selectedPartition()
     if (selectedDevice() == nullptr || selectedDevice()->partitionTable() == nullptr || partTableWidget().activeWidget() == nullptr)
         return nullptr;
 
-    // The active partition we get from the part table widget is const; we need non-const.
-    // So take the first sector and find the partition in the selected device's
-    // partition table.
-    const Partition* activePartition = partTableWidget().activeWidget()->partition();
-    return selectedDevice()->partitionTable()->findPartitionBySector(activePartition->firstSector(), PartitionRole(PartitionRole::Any));
+    return partTableWidget().activeWidget()->partition();
 }
 
 void PartitionManagerWidget::setSelectedDevice(const QString& deviceNode)
@@ -212,8 +208,8 @@ static QTreeWidgetItem* createTreeWidgetItem(const Partition& p)
     int i = 0;
     item->setText(i++, p.deviceNode());
 
-    if (p.roles().has(PartitionRole::Luks) && p.fileSystem().name() != p.fileSystem().nameForType(FileSystem::Luks))
-        item->setText(i, xi18nc("@item:intable Encrypted file systems, e.g. btrfs[luks]", "%1 [%2]", p.fileSystem().name(), p.fileSystem().nameForType(FileSystem::Luks)));
+    if (p.roles().has(PartitionRole::Luks) && (p.fileSystem().name() != p.fileSystem().nameForType(FileSystem::Type::Luks) && p.fileSystem().name() != p.fileSystem().nameForType(FileSystem::Type::Luks2)))
+        item->setText(i, xi18nc("@item:intable Encrypted file systems, e.g. btrfs[Encrypted]", "%1 [Encrypted]", p.fileSystem().name()));
     else
         item->setText(i, p.fileSystem().name());
     item->setIcon(i, createFileSystemColor(p.fileSystem().type(), 14));
@@ -226,6 +222,9 @@ static QTreeWidgetItem* createTreeWidgetItem(const Partition& p)
 
     item->setText(i++, p.fileSystem().label());
     item->setText(i++, p.fileSystem().uuid());
+    item->setText(i++, p.label());
+    item->setText(i++, p.uuid());
+
     item->setText(i++, Capacity::formatByteSize(p.capacity()));
     item->setText(i++, Capacity::formatByteSize(p.used()));
     item->setText(i++, Capacity::formatByteSize(p.available()));
@@ -570,11 +569,11 @@ void PartitionManagerWidget::onDeletePartition(bool shred)
     }
 
     if (shred && Config::shredSource() == Config::EnumShredSource::random)
-        operationStack().push(new DeleteOperation(*selectedDevice(), selectedPartition(), DeleteOperation::RandomShred));
+        operationStack().push(new DeleteOperation(*selectedDevice(), selectedPartition(), DeleteOperation::ShredAction::RandomShred));
     else if (shred && Config::shredSource() == Config::EnumShredSource::zeros)
-        operationStack().push(new DeleteOperation(*selectedDevice(), selectedPartition(), DeleteOperation::ZeroShred));
+        operationStack().push(new DeleteOperation(*selectedDevice(), selectedPartition(), DeleteOperation::ShredAction::ZeroShred));
     else
-        operationStack().push(new DeleteOperation(*selectedDevice(), selectedPartition(), DeleteOperation::NoShred));
+        operationStack().push(new DeleteOperation(*selectedDevice(), selectedPartition(), DeleteOperation::ShredAction::NoShred));
 }
 
 void PartitionManagerWidget::onShredPartition()
@@ -606,7 +605,7 @@ void PartitionManagerWidget::onResizePartition()
     qint64 freeBefore = selectedDevice()->partitionTable()->freeSectorsBefore(p);
     qint64 freeAfter = selectedDevice()->partitionTable()->freeSectorsAfter(p);
 
-    if (selectedDevice()->type() == Device::LVM_Device) {
+    if (selectedDevice()->type() == Device::Type::LVM_Device) {
         freeBefore = 0;
         freeAfter  = selectedDevice()->partitionTable()->freeSectors();
     }
@@ -615,7 +614,7 @@ void PartitionManagerWidget::onResizePartition()
 
     if (dlg->exec() == QDialog::Accepted) {
         if (dlg->resizedFirstSector() == p.firstSector() && dlg->resizedLastSector() == p.lastSector())
-            Log(Log::information) << xi18nc("@info:status", "Partition <filename>%1</filename> has the same position and size after resize/move. Ignoring operation.", p.deviceNode());
+            Log(Log::Level::information) << xi18nc("@info:status", "Partition <filename>%1</filename> has the same position and size after resize/move. Ignoring operation.", p.deviceNode());
         else
             operationStack().push(new ResizeOperation(*selectedDevice(), p, dlg->resizedFirstSector(), dlg->resizedLastSector()));
     }
@@ -761,13 +760,11 @@ void PartitionManagerWidget::onBackupPartition()
     }
 
     QString fileName = QFileDialog::getSaveFileName(this);
-//  QString fileName = "/tmp/backuptest.img";
 
     if (fileName.isEmpty())
         return;
 
-    if (!QFile::exists(fileName) || KMessageBox::warningContinueCancel(this, xi18nc("@info", "Do you want to overwrite the existing file <filename>%1</filename>?", fileName), xi18nc("@title:window", "Overwrite Existing File?"), KGuiItem(xi18nc("@action:button", "Overwrite File"), QStringLiteral("arrow-right")), KStandardGuiItem::cancel()) == KMessageBox::Continue)
-        operationStack().push(new BackupOperation(*selectedDevice(), *selectedPartition(), fileName));
+    operationStack().push(new BackupOperation(*selectedDevice(), *selectedPartition(), fileName));
 }
 
 void PartitionManagerWidget::onRestorePartition()
