@@ -24,6 +24,8 @@
 #include <core/partitiontable.h>
 #include <fs/lvm2_pv.h>
 
+#include <ops/deleteoperation.h>
+
 #include <util/capacity.h>
 #include <util/helpers.h>
 
@@ -35,9 +37,11 @@
     @param parent pointer to the parent widget
     @param d the Device to show properties for
 */
-ResizeVolumeGroupDialog::ResizeVolumeGroupDialog(QWidget* parent, VolumeManagerDevice* d, QVector<const Partition*>& partList)
+ResizeVolumeGroupDialog::ResizeVolumeGroupDialog(QWidget* parent, VolumeManagerDevice* d, QVector<const Partition*>& partList, QList<Device*> devices, QList<Operation*> pendingOps)
     : VolumeGroupDialog(parent, d->name(), partList)
+    , m_Devices(devices)
     , m_Device(d)
+    , m_PendingOps(pendingOps)
 {
     setWindowTitle(xi18nc("@title:window", "Resize Volume Group"));
 
@@ -51,7 +55,20 @@ ResizeVolumeGroupDialog::ResizeVolumeGroupDialog(QWidget* parent, VolumeManagerD
 void ResizeVolumeGroupDialog::setupDialog()
 {
     if (dialogWidget().volumeType().currentText() == QStringLiteral("LVM")) {
-        for (const auto &p : qAsConst(LVM::pvList)) {
+        for (const auto &p : qAsConst(LVM::pvList::list())) {
+            bool toBeDeleted = false;
+
+            // Ignore partitions that are going to be deleted
+            for (const auto &o : qAsConst(m_PendingOps)) {
+                if (dynamic_cast<DeleteOperation *>(o) && o->targets(*p.partition())) {
+                    toBeDeleted = true;
+                    break;
+                }
+            }
+
+            if (toBeDeleted)
+                continue;
+
             if (p.isLuks())
                 continue;
             if (p.vgName() == device()->name())
@@ -59,6 +76,32 @@ void ResizeVolumeGroupDialog::setupDialog()
             else if (p.vgName() == QString() && !LvmDevice::s_DirtyPVs.contains(p.partition())) // TODO: Remove LVM PVs in current VG
                 dialogWidget().listPV().addPartition(*p.partition(), false);
         }
+
+        for (const Device *d : qAsConst(m_Devices)) {
+            if (d->partitionTable() != nullptr) {
+                for (const Partition *p : qAsConst(d->partitionTable()->children())) {
+                    // Looking if there is another VG creation that contains this partition
+                    if (LvmDevice::s_DirtyPVs.contains(p))
+                        continue;
+
+                    // Including new LVM PVs (that are currently in OperationStack and that aren't at other VG creation)
+                    if (p->state() == Partition::State::New) {
+                        if (p->fileSystem().type() == FileSystem::Type::Lvm2_PV)
+                            dialogWidget().listPV().addPartition(*p, false);
+                        else if (p->fileSystem().type() == FileSystem::Type::Luks || p->fileSystem().type() == FileSystem::Type::Luks2) {
+                            FileSystem *fs = static_cast<const FS::luks *>(&p->fileSystem())->innerFS();
+
+                            if (fs->type() == FileSystem::Type::Lvm2_PV)
+                                dialogWidget().listPV().addPartition(*p, false);
+                        }
+                    }
+                }
+            }
+        }
+
+        for (const Partition *p : qAsConst(LvmDevice::s_OrphanPVs))
+            if (!LvmDevice::s_DirtyPVs.contains(p))
+                dialogWidget().listPV().addPartition(*p, false);
     }
 
     //update used size and LV infos
